@@ -5,7 +5,7 @@ use warnings;
 package MooX::Press;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.037';
+our $VERSION   = '0.038';
 
 use Types::Standard 1.008003 -is, -types;
 use Types::TypeTiny qw(ArrayLike HashLike);
@@ -805,11 +805,18 @@ sub _make_package {
 		}
 		
 		if ($opts{abstract}) {
-			'namespace::clean'->clean_subroutines($qname, 'new');
-			my $orig_can = $qname->can('can');
+			my $orig_can   = $qname->can('can');
+			my $orig_BUILD = do { no strict 'refs'; exists(&{"$qname\::BUILD"}) ? \&{"$qname\::BUILD"} : sub {} };
+			'namespace::clean'->clean_subroutines($qname, 'new', 'BUILD');
 			$builder->install_methods($qname, {
-				can => sub { return if $_[0] eq $qname && $_[1] eq 'new'; goto $orig_can },
-				new => sub { require Carp; Carp::croak('abstract class') },
+				can   => sub {
+					if ((ref($_[0])||$_[0]) eq $qname and $_[1] eq 'new') { return; };
+					goto $orig_can;
+				},
+				BUILD => sub {
+					if (ref($_[0]) eq $qname) { require Carp; Carp::croak('abstract class'); };
+					goto $orig_BUILD;
+				},
 			});
 		}
 		
